function [forecastData]=UpdateForecastData(forecastData,MatchUpDir)
%
% Description: Assemble data for a hindcast experiment. The SWFT GUI update
%    several top level fields and variable lists for forecast and covariate
%    variables. This routine update other attributes of the forecast
%    dataset.
% Usage: [forecastData]=UpdateForecastData(forecastData,MatchUpDir)
%

%
% Set-up limits for training and validation time intervals for forecast and
% covariate vaiables.
%
forecastData.ForecastVar.LastTrainingDateNum=...
    forecastData.CurrentEpoc-forecastData.DataLatency;
forecastData.ForecastVar.FirstTrainingDateNum=...
    forecastData.CurrentEpoc-forecastData.DataLatency-forecastData.nTrainingDay;
forecastData.ForecastVar.FirstValidationDateNum=...
    forecastData.CurrentEpoc+forecastData.ForecastPeriod;
forecastData.ForecastVar.LastValidationDateNum=...
    forecastData.CurrentEpoc+forecastData.ForecastPeriod+forecastData.nValidationDay;
%
% Load training and validation data for forecast variables
%
LastDateNum=forecastData.ForecastVar.LastTrainingDateNum;
FirstDateNum=forecastData.ForecastVar.FirstTrainingDateNum;
[forecastData.ForecastVar.TrainingData]=extractMatchupData(forecastData.ForecastVar.VarLabels,...
    FirstDateNum,LastDateNum,MatchUpDir);
LastDateNum=forecastData.ForecastVar.LastValidationDateNum;
FirstDateNum=forecastData.ForecastVar.FirstValidationDateNum;
[forecastData.ForecastVar.ValidationData]=extractMatchupData(forecastData.ForecastVar.VarLabels,...
    FirstDateNum,LastDateNum,MatchUpDir);
%
% Update variable attribute tables for forecast varable
%
forecastData.ForecastVar=updateAttrib(forecastData.ForecastVar,MatchUpDir);

%
% Search for longest time history used among the covariates
%
forecastData.DataVar.LastTrainingDateNum=...
    forecastData.CurrentEpoc-forecastData.DataLatency-forecastData.ForecastPeriod;
DataHistory=-inf;
[VarInfo]=getVarInfo(forecastData.DataVar.VarLabels,MatchUpDir);
nVar=length(VarInfo);
for iVar=1:nVar
    if ~isempty(VarInfo(iVar).TimeStamp)
        DataHistory=max([DataHistory,VarInfo(iVar).TimeStamp]);
    end
end
%
% The first time sample is the latest data available for training.
%
DataHistory=(DataHistory-1)/8;
forecastData.DataVar.FirstTrainingDateNum=...
    forecastData.CurrentEpoc-forecastData.DataLatency-forecastData.ForecastPeriod-forecastData.nTrainingDay-DataHistory;
forecastData.DataVar.FirstValidationDateNum=...
    forecastData.CurrentEpoc+forecastData.ForecastPeriod-forecastData.DataLatency-DataHistory;
forecastData.DataVar.LastValidationDateNum=...
    forecastData.CurrentEpoc+forecastData.ForecastPeriod-forecastData.DataLatency+forecastData.nValidationDay;
DataSetName={forecastData.DataVar.Attrib(:).DataSet};
DataFieldList={forecastData.DataVar.Attrib(:).DataFieldList};
LastDateNum=forecastData.DataVar.LastTrainingDateNum;
FirstDateNum=forecastData.DataVar.FirstTrainingDateNum;
%
% Load traning and validation data for explanatory variables.
%
[forecastData.DataVar.TrainingData]=extractMatchupData(forecastData.DataVar.VarLabels,...
    FirstDateNum,LastDateNum,MatchUpDir);
LastDateNum=forecastData.DataVar.LastValidationDateNum;
FirstDateNum=forecastData.DataVar.FirstValidationDateNum;
[forecastData.DataVar.ValidationData]=extractMatchupData(forecastData.DataVar.VarLabels,...
    FirstDateNum,LastDateNum,MatchUpDir);
%
% Update variable attribute tables for covariate variables
%
forecastData.DataVar=updateAttrib(forecastData.DataVar,MatchUpDir);
%
% Constructing explanatory variable array and array labels.
%
[forecastData.ForecastVar]=updateDataArrays(forecastData.ForecastVar,MatchUpDir);
[forecastData.DataVar]=updateDataArrays(forecastData.DataVar,MatchUpDir);
return;
end