function [VarInfo]=getVarInfo(VarLabels,SWFTData_Path)
%
% Description: Find the information about a variable in the database. This
%     routine parses variable names in the variable labels to find its
%     native name, local statistics and time stamp. This routine also
%     serves to bridge the forecast datasets created using old version of
%     the SWFT database.
%
filelist=dir([SWFTData_Path,filesep,'GIMvSpace_Matchup*.mat']);
if isempty(filelist)
    disp(['getVarInfo: Folder ',SWFTData_Path,' does not contain SWFT data files.']);
    DataCategory=[];
    return;
end
%
% Check version of SWFT match-up database.
%
SWFT_Dataset=load([filelist(1).folder,filesep,filelist(1).name]);
if ~isfield(SWFT_Dataset,'SWFT_Dataset')
    disp('getVarInfo: Format of SWFT database has changed for the new SWFT. Please find new match-up data.');
    return;
else
    SWFT_Dataset=SWFT_Dataset.SWFT_Dataset;
end
%
nVariable=length(VarLabels);
VarInfo=struct('VarName',cell(nVariable,1));
LocalStats={'max','min','median','var','mean'};
for iVariable=1:nVariable
    %
    % Finding the time stamp of the variable.
    %
    ind=strfind(VarLabels(iVariable).VariableName,'_');
    TimeStamp=[];
    if ~isempty(ind)
        TimeStamp=str2num(VarLabels(iVariable).VariableName(ind(end)+1:end));
    end
    if isempty(TimeStamp)
        VarInfo(iVariable).VarName=VarLabels(iVariable).VariableName;
    else
        VarInfo(iVariable).VarName=VarLabels(iVariable).VariableName(1:ind(end)-1);
    end
    VarInfo(iVariable).TimeStamp=TimeStamp;
    %
    % Mapping the old names of dataset to their new name.
    %
    switch VarLabels(iVariable).DataSetName
        case 'DataSet'
            VarInfo(iVariable).DataSet='Physical';
        case 'SingleAttrib_Anaomaly'
            VarInfo(iVariable).DataSet='AnomalyFlags';
        otherwise
            VarInfo(iVariable).DataSet=VarLabels(iVariable).DataSetName;
    end
    %
    v=getfield(SWFT_Dataset,VarInfo(iVariable).DataSet);
    %
    % Variable names composed of its native name such as Vx and its local
    % statistics label such as 'max'
    %
    varlist=fieldnames(v);
    ind=find(strcmp(varlist,VarInfo(iVariable).VarName)==1);
    if isempty(ind)
        VarInfo=[];
        disp(['getVarInfo: Fatal error. Cannot find variable ',VarInfo(iVariable).VarName,...
            ' in the database.']);
        return;
    end
    u=getfield(v,VarInfo(iVariable).VarName);
    VarInfo(iVariable).Category=u.Category;
    %
    % Find the native name of a variablbe. Native name is useful for
    % communication with users. However, internally, variable names already
    % contains local statistics label.
    %
    ind=strfind(VarInfo(iVariable).VarName,'_');
    if isempty(ind)
        VarInfo(iVariable).NativeName=VarInfo(iVariable).VarName;
    elseif ~isempty(find(strcmpi(LocalStats,VarInfo(iVariable).VarName(ind(end)+1:end))==1))
        VarInfo(iVariable).NativeName=VarInfo(iVariable).VarName(1:ind(end)-1);
    else
        VarInfo(iVariable).NativeName=VarInfo(iVariable).VarName;
    end
end
return;
end