function [Var]=updateDataArrays(Var,MatchupDir)
%
% Description: Construct training and validation data arrays from loaded
%   data strcuture.
%
[VarInfo]=getVarInfo(Var.VarLabels,MatchupDir);
nVar=length(VarInfo);
if isempty(VarInfo(1).TimeStamp)
    maxTimeStamp=1;
else
    maxTimeStamp=max([VarInfo(:).TimeStamp]);
end
nTrainingPts=length(Var.TrainingData.DateNum_Start)-maxTimeStamp+1;
nValidationPts=length(Var.ValidationData.DateNum_Start)-maxTimeStamp+1;
Var.TrainingArray=NaN(nVar,nTrainingPts);
Var.ValidationArray=NaN(nVar,nValidationPts);
for iVar=1:nVar
    %
    % Compatibility to old version of SWFT Database
    %
    if ~isfield(Var.TrainingData,VarInfo(iVar).DataSet)
        switch VarInfo(iVar).DataSet
            case 'Physical'
                VarInfo(iVar).DataSet='DataSet';
            case 'AnomalyFlags'
                VarInfo(iVar).DataSet='SingleAttrib_Anaomaly';
        end
    end
    %
    % Verify the existence of required field.
    %
    if ~isfield(Var.TrainingData,VarInfo(iVar).DataSet)
        error(['updateDataArrays: Required date set: ',VarInfo(iVar).DataSet,...
            ' has not been properly initialized.']);
    end
    DataSet=getfield(Var.TrainingData,VarInfo(iVar).DataSet);
    v=getfield(DataSet,VarInfo(iVar).VarName);
    if isempty(VarInfo(iVar).TimeStamp)
        TimeStamp=1;
    else
        TimeStamp=VarInfo(iVar).TimeStamp;
    end
    Var.TrainingArray(iVar,:)=v(TimeStamp:nTrainingPts+TimeStamp-1);
    DataSet=getfield(Var.ValidationData,VarInfo(iVar).DataSet);
    v=getfield(DataSet,VarInfo(iVar).VarName);
    Var.ValidationArray(iVar,:)=v(TimeStamp:nValidationPts+TimeStamp-1);
end
return
end