function visualizeMultiLinearReg(forecastData)
%
% Description: Visualize a forecast based on multilinear regression.
%
nforecastVar=length(forecastData.ForecastVar.VarLabels);
[Verification]=predict(forecastData.Forecast,forecastData.DataVar.TrainingArray');
[Validation]=predict(forecastData.Forecast,forecastData.DataVar.ValidationArray');
cHandle=zeros(4,1);
for iVar=1:nforecastVar
    figure;
    set(gcf,'Position',[340   800   840   540],'Color','w');
    h1=subplot('Position',[0.1,0.6,0.8,0.25]);
    vmin=min([forecastData.ForecastVar.TrainingArray(iVar,:),...
        forecastData.ForecastVar.ValidationArray(iVar,:),...
        Verification(:,iVar)',Validation(:,iVar)']);
    vmax=max([forecastData.ForecastVar.TrainingArray(iVar,:),...
        forecastData.ForecastVar.ValidationArray(iVar,:),...
        Verification(:,iVar)',Validation(:,iVar)']);
    fill([forecastData.ForecastVar.TrainingData.DateNum_Start(1),...
        forecastData.ForecastVar.TrainingData.DateNum_Start(end),...
        forecastData.ForecastVar.TrainingData.DateNum_Start(end),...
        forecastData.ForecastVar.TrainingData.DateNum_Start(1)],...
        [vmin,vmin,vmax,vmax],[0.8,0.8,0.8]);
    hold on
    cHandle(1)=plot(forecastData.ForecastVar.TrainingData.DateNum_Start,...
        forecastData.ForecastVar.TrainingArray(iVar,:),'b');
    cHandle(2)=plot(forecastData.ForecastVar.ValidationData.DateNum_Start,...
        forecastData.ForecastVar.ValidationArray(iVar,:),'k');
    cHandle(3)=plot(forecastData.ForecastVar.TrainingData.DateNum_Start,...
        Verification(:,iVar),'m');
    cHandle(4)=plot(forecastData.ForecastVar.ValidationData.DateNum_Start,...
        Validation(:,iVar),'r');
    datetick('x',5);
    axis tight
    set(gca,'XAxisLocation','top');
    c=get(gca,'Children');
    legend(cHandle,{'True','Pred. True','Model Fit','Pred'},'Location','SouthWest');
    xlabel('Date (month)')
    %
    h2=subplot('Position',[0.1,0.1,0.4,0.5]);
    plot(forecastData.ForecastVar.TrainingArray(iVar,:),...
        Verification(:,iVar)','o');
    axis tight
    hold on
    plot(forecastData.ForecastVar.ValidationArray(iVar,:),...
        Validation(:,iVar)','or');
    xlim=get(gca,'XLim');
    plot(xlim,xlim,'k');
    xlabel('Truth');
    ylabel('Model Fit');
    legend(gca,{'Verification','Validation'},'Location','NorthWest');
    %
    h3=subplot('Position',[0.5,0.1,0.4,0.5]);
    nPts=length(Verification(:,iVar));
    diff=forecastData.ForecastVar.TrainingArray(iVar,:)-...
        Verification(:,iVar)';
    [Freq,X]=hist(diff,20,'FaceColor','b');
    bar(X,Freq/nPts);
    dStd=std(diff(~isnan(diff)));
    dMean=mean(diff(~isnan(diff)));
    text('Unit','Normalized','Position',[0.75,0.9],'String',['Mean: ',num2str(dMean)],'FontSize',[10]);
    text('Unit','Normalized','Position',[0.75,0.85],'String',['STD: ',num2str(dStd)],'FontSize',[10]);
    hold on
    nPts=length(Validation(:,iVar));
    diff=forecastData.ForecastVar.ValidationArray(iVar,:)-...
        Validation(:,iVar)';
    [Freq,X]=hist(diff,20);
    bar(X,-Freq/nPts,'FaceColor','r');
    dMean=mean(diff(~isnan(diff)));
    dStd=std(diff(~isnan(diff)));
    xlabel('Model-Truth')
    ylabel('Frequency');
    text('Unit','Normalized','Position',[0.75,0.15],'String',['Mean: ',num2str(dMean)],'FontSize',[10]);
    text('Unit','Normalized','Position',[0.75,0.1],'String',['STD: ',num2str(dStd)],'FontSize',[10]);
    set(gca,'YAxisLocation','right');
    legend(gca,{'Verification','Validation'},'Location','NorthWest');
    %
    ht=subplot('Position',[0.1,0.92,0.8,0.01]);
    axis off
    VarName=[forecastData.ForecastVar.VarLabels(iVar).VariableName,'(',...
        forecastData.ForecastVar.VarLabels(iVar).DataSetName,')'];
    title([num2str(forecastData.ForecastPeriod),'-day Forecast for ',VarName, ' with Data Latency of ',...
        num2str(forecastData.DataLatency), ...
        ' day Trained with ',num2str(forecastData.nTrainingDay),' Days of Data Prior to ',...
        datestr(forecastData.CurrentEpoc,0)],'Interpreter','none');
end;
return
end    